@@ -159,11 +159,11 @@ async def new_position(
 
         logging.info(f"\t\tLimit Price: {limit_price}. Amount: {amount}")
 
-        limit_price = float(limit_price)
-        amount = float(amount)
 
         first_currency_units = CEROS[first_currency_code]
-        second_currency_units = CEROS(second_currency_code)
+        second_currency_units = CEROS[second_currency_code]
+        limit_price = float(round(limit_price, 2))
+        amount = float(round(amount, first_currency_code))
 
         logging.info(f"{first_currency_code } Digits: {first_currency_units}")
         logging.info(f"{second_currency_code } Digits: {second_currency_units}")
